PCWSTR

Struct PCWSTR 

#[repr(transparent)]
pub struct PCWSTR(pub *const u16);
A pointer to a constant null-terminated string of 16-bit Unicode characters.

Tuple Fields

0: *const u16

Implementations

Source

impl PCWSTR

pub const fn from_raw(ptr: *const u16) -> Self

Constructs a PCWSTR from a raw pointer.

pub const fn null() -> Self

Constructs a null PCWSTR.

pub const fn as_ptr(&self) -> *const u16

Returns the raw pointer.

pub fn is_null(&self) -> bool

Returns whether the pointer is null.

pub unsafe fn len(&self) -> usize

Returns the string length without the trailing null.

Safety

The PCWSTR’s pointer needs to be valid for reads up until and including the next \0.

pub unsafe fn is_empty(&self) -> bool

Returns whether the string is empty.

Safety

The PCWSTR’s pointer needs to be valid for reads up until and including the next \0.

pub unsafe fn as_wide(&self) -> &[u16]

Returns the string data without the trailing null.

Safety

The PCWSTR’s pointer needs to be valid for reads up until and including the next \0.

pub unsafe fn to_string(&self) -> Result<String, FromUtf16Error>

Copies the string into a Rust String.

Safety

See the safety information for PCWSTR::as_wide.

pub unsafe fn to_hstring(&self) -> HSTRING

Copies the string into an HSTRING.

Safety

See the safety information for PCWSTR::as_wide.

pub unsafe fn display(&self) -> impl Display + '_

Returns a display adapter for the string.

Safety

See the safety information for PCWSTR::as_wide.