PWSTR

Struct PWSTR 

#[repr(transparent)]
pub struct PWSTR(pub *mut u16);
A pointer to a null-terminated string of 16-bit Unicode characters.

Tuple Fields

0: *mut u16

Implementations

Source

impl PWSTR

pub const fn from_raw(ptr: *mut u16) -> Self

Constructs a PWSTR from a raw pointer.

pub const fn null() -> Self

Constructs a null PWSTR.

pub const fn as_ptr(&self) -> *mut u16

Returns the raw pointer.

pub fn is_null(&self) -> bool

Returns whether the pointer is null.

pub unsafe fn len(&self) -> usize

Returns the string length without the trailing null.

Safety

The PWSTR’s pointer needs to be valid for reads up until and including the next \0.

pub unsafe fn is_empty(&self) -> bool

Returns whether the string is empty.

Safety

The PWSTR’s pointer needs to be valid for reads up until and including the next \0.

pub unsafe fn as_wide(&self) -> &[u16]

Returns the string data without the trailing null.

Safety

The PWSTR’s pointer needs to be valid for reads up until and including the next \0.

pub unsafe fn to_string(&self) -> Result<String, FromUtf16Error>

Copies the string into a Rust String.

Safety

See the safety information for PWSTR::as_wide.

pub unsafe fn to_hstring(&self) -> HSTRING

Copies the string into an HSTRING.

Safety

See the safety information for PWSTR::as_wide.

pub unsafe fn display(&self) -> impl Display + '_

Returns a display adapter for the string.

Safety

See the safety information for PWSTR::as_wide.